==> red5pro-0.0.14.tar.gz: ios/Classes/Red5ProStreamController.m <==
//
//  Red5ProStreamController.m
//  red5pro
//
//  Created by Jaydip Godhani on 23/11/21.
//

#import "Red5ProStreamController.h"

@interface Red5ProStreamController () {
    R5Configuration *config;
    R5Stream *stream;
    //R5Camera *r5Camera;
    
    NSString *strStreamName;
    int recordType;
}

@end

@implementation Red5ProStreamController

- (void)viewDidLoad {
    [super viewDidLoad];
}
- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    [self setupStreaming];
}

- (void)viewWillDisappear:(BOOL)animated {
    [super viewWillDisappear:animated];
    [self stopStreaming];
}

//MARK: - Setup Configuratiom and Setup Stream
-(void)setupConfiguration {
    config = [R5Configuration new];
    config.host = self.strHostName;
    config.port = [self.strPort intValue];
    config.contextName = self.strContextName;
    config.licenseKey = self.strLicencekey;
    config.protocol = [self intToR5StreamProtocol:self.protocol];
    self.isPublishing = false;
}

-(void)setupStreaming  {
    NSArray *captureDeviceType = @[AVCaptureDeviceTypeBuiltInWideAngleCamera];
    AVCaptureDeviceDiscoverySession *captureDevice =
    [AVCaptureDeviceDiscoverySession
     discoverySessionWithDeviceTypes:captureDeviceType
     mediaType:AVMediaTypeVideo
     position:AVCaptureDevicePositionUnspecified];
            
    //// Set the streaming camera
    R5Camera *r5Camera = [[R5Camera alloc] initWithDevice:captureDevice.devices.lastObject andBitRate:[self.strBitrate intValue]];
    r5Camera.fps = (int)self.fps;
    r5Camera.width = (int)self.frameWidth;
    r5Camera.height = (int)self.frameHeight;
    r5Camera.orientation = [self getCameraorientation:captureDevice.devices.lastObject];
    
    
    AVCaptureDevice *audioDevice= [AVCaptureDevice defaultDeviceWithMediaType:AVMediaTypeAudio];
    R5Microphone *microphone = [[R5Microphone new] initWithDevice:audioDevice];
    
    R5Connection *connection = [[R5Connection new] initWithConfig:config];
    
    stream = [[R5Stream new] initWithConnection:connection];
    [stream attachVideo:r5Camera];
    [stream attachAudio:microphone];
    
    [stream setDelegate:self];
    [self attachStream:stream];
    [self showPreview:YES];
}

//MARK: - Start stream usign streamkey name and type
-(void)startStreaming:(NSString *)streamName type:(int)type {
    strStreamName = streamName;
    recordType = type;
    
    [self showPreview:NO];
    //// This line is used for showing the `stream packaet` is uploded or not
    //[self showDebugInfo:true];
    
    //// Publisher publish the stream according to the type
    [stream publish:streamName type:[self intToRecordType:type]];
    self.isPublishing = true;
}
-(void)stopStreaming {
    [stream stop];
    [stream setDelegate:nil];
    [self setupStreaming];
    self.isPublishing = false;
}

//MARK:- Retrive `Record Type` and `Protocol`
-(enum R5RecordType)intToRecordType:(int)type {
    switch (type) {
        case 0:
            return R5RecordTypeLive;
        case 1:
            return R5RecordTypeRecord;
        case 2:
            return R5RecordTypeAppend;
        default:
            return R5RecordTypeLive;
    }
}
-(enum r5_protocol)intToR5StreamProtocol:(NSInteger)protocol {
    switch (protocol) {
        case 0:
            return r5_rtsp;
        case 1:
            return r5_rtsp;
        case 2:
            return r5_srtp;
        case 3:
            return r5_null_srtp;
        default:
            return r5_srtp;
    }
}
//MARK: - Switch camera
-(void)switchCamera {
    R5Camera *camera = (R5Camera *)[stream getVideoSource];
    AVCaptureDevice *device = camera.device;
    [self showPreview:true];
    if (device.position == AVCaptureDevicePositionFront) {
        NSArray *captureDeviceType = @[AVCaptureDeviceTypeBuiltInWideAngleCamera];
        AVCaptureDeviceDiscoverySession *captureDevice =
        [AVCaptureDeviceDiscoverySession
         discoverySessionWithDeviceTypes:captureDeviceType
         mediaType:AVMediaTypeVideo
         position:AVCaptureDevicePositionBack];
        
        camera.device = captureDevice.devices.lastObject;
        camera.orientation = [self getCameraorientation:captureDevice.devices.lastObject];;
    } else {
        NSArray *captureDeviceType = @[AVCaptureDeviceTypeBuiltInWideAngleCamera];
        AVCaptureDeviceDiscoverySession *captureDevice =
        [AVCaptureDeviceDiscoverySession
         discoverySessionWithDeviceTypes:captureDeviceType
         mediaType:AVMediaTypeVideo
         position:AVCaptureDevicePositionFront];
        
        camera.device = captureDevice.devices.lastObject;
        camera.orientation = [self getCameraorientation:captureDevice.devices.lastObject];
    }
    if (self.isPublishing) {
        [self showPreview:false];
    }
}

-(int)getCameraorientation:(AVCaptureDevice *)device {
    switch (device.position) {
        case AVCaptureDevicePositionFront:
            return 90;
        case AVCaptureDevicePositionBack:
            return 90;
        default:
            return 90;
    }
}

-(void)onR5StreamStatus:(R5Stream *)stream withStatus:(int)statusCode withMessage:(NSString *)msg {
    NSLog(@"Stream: %s - %@", r5_string_for_status(statusCode), msg);
}

@end

==> red5pro-0.0.21.tar.gz: ios/Classes/Red5ProStreamController.m <==
//
//  Red5ProStreamController.m
//  red5pro
//
//  Created by Jaydip Godhani on 23/11/21.
//

#import "Red5ProStreamController.h"

@interface Red5ProStreamController () {
    R5Configuration *config;
    R5Stream *stream;
    //R5Camera *r5Camera;
    
    NSString *strStreamName;
    int recordType;
}

@end

@implementation Red5ProStreamController

- (void)viewDidLoad {
    [super viewDidLoad];
}
- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    [self setupStreaming];
}

- (void)viewWillDisappear:(BOOL)animated {
    [super viewWillDisappear:animated];
    [self stopStreaming];
}

//MARK: - Setup Configuratiom and Setup Stream
-(void)setupConfiguration:(BOOL)setuoStream {
    config = [R5Configuration new];
    config.host = self.strHostName;
    config.port = [self.strPort intValue];
    config.contextName = self.strContextName;
    config.licenseKey = self.strLicencekey;
    config.protocol = [self intToR5StreamProtocol:self.protocol];
    self.isPublishing = false;
    if (setuoStream) {
        [self setupStreaming];
    }
}

-(void)setupStreaming  {
    NSArray *captureDeviceType = @[AVCaptureDeviceTypeBuiltInWideAngleCamera];
    AVCaptureDeviceDiscoverySession *captureDevice =
    [AVCaptureDeviceDiscoverySession
     discoverySessionWithDeviceTypes:captureDeviceType
     mediaType:AVMediaTypeVideo
     position:AVCaptureDevicePositionUnspecified];
            
    //// Set the streaming camera
    R5Camera *r5Camera = [[R5Camera alloc] initWithDevice:captureDevice.devices.lastObject andBitRate:[self.strBitrate intValue]];
    r5Camera.fps = (int)self.fps;
    r5Camera.width = (int)self.frameWidth;
    r5Camera.height = (int)self.frameHeight;
    r5Camera.orientation = [self getCameraorientation:captureDevice.devices.lastObject];
    
    AVCaptureDevice *audioDevice= [AVCaptureDevice defaultDeviceWithMediaType:AVMediaTypeAudio];
    R5Microphone *microphone = [[R5Microphone new] initWithDevice:audioDevice];
    R5Connection *connection = [[R5Connection new] initWithConfig:config];
    stream = [[R5Stream new] initWithConnection:connection];
    [stream attachVideo:r5Camera];
    if (self.strHostName != nil) {
        [stream attachAudio:microphone];
    }
    [stream setDelegate:self];
    [self attachStream:stream];
    [self showPreview:YES];
}

//MARK: - Start stream usign streamkey name and type
-(void)startStreaming:(NSString *)streamName type:(int)type {
    strStreamName = streamName;
    recordType = type;
    
    [self showPreview:NO];
    //// This line is used for showing the `stream packaet` is uploded or not
    //[self showDebugInfo:true];
    
    //// Publisher publish the stream according to the type
    [stream publish:streamName type:[self intToRecordType:type]];
    self.isPublishing = true;
}
-(void)stopStreaming {
    [stream stop];
    [stream setDelegate:nil];
    [self setupStreaming];
    self.isPublishing = false;
}

//MARK:- Retrive `Record Type` and `Protocol`
-(enum R5RecordType)intToRecordType:(int)type {
    switch (type) {
        case 0:
            return R5RecordTypeLive;
        case 1:
            return R5RecordTypeRecord;
        case 2:
            return R5RecordTypeAppend;
        default:
            return R5RecordTypeLive;
    }
}
-(enum r5_protocol)intToR5StreamProtocol:(NSInteger)protocol {
    switch (protocol) {
        case 0:
            return r5_rtsp;
        case 1:
            return r5_rtsp;
        case 2:
            return r5_srtp;
        case 3:
            return r5_null_srtp;
        default:
            return r5_srtp;
    }
}
//MARK: - Switch camera
-(void)switchCamera {
    R5Camera *camera = (R5Camera *)[stream getVideoSource];
    AVCaptureDevice *device = camera.device;
    [self showPreview:true];
    if (device.position == AVCaptureDevicePositionFront) {
        NSArray *captureDeviceType = @[AVCaptureDeviceTypeBuiltInWideAngleCamera];
        AVCaptureDeviceDiscoverySession *captureDevice =
        [AVCaptureDeviceDiscoverySession
         discoverySessionWithDeviceTypes:captureDeviceType
         mediaType:AVMediaTypeVideo
         position:AVCaptureDevicePositionBack];
        
        camera.device = captureDevice.devices.lastObject;
        camera.orientation = [self getCameraorientation:captureDevice.devices.lastObject];;
    } else {
        NSArray *captureDeviceType = @[AVCaptureDeviceTypeBuiltInWideAngleCamera];
        AVCaptureDeviceDiscoverySession *captureDevice =
        [AVCaptureDeviceDiscoverySession
         discoverySessionWithDeviceTypes:captureDeviceType
         mediaType:AVMediaTypeVideo
         position:AVCaptureDevicePositionFront];
        
        camera.device = captureDevice.devices.lastObject;
        camera.orientation = [self getCameraorientation:captureDevice.devices.lastObject];
    }
    if (self.isPublishing) {
        [self showPreview:false];
    }
}

-(int)getCameraorientation:(AVCaptureDevice *)device {
    switch (device.position) {
        case AVCaptureDevicePositionFront:
            return 90;
        case AVCaptureDevicePositionBack:
            return 90;
        default:
            return 90;
    }
}

-(void)onR5StreamStatus:(R5Stream *)stream withStatus:(int)statusCode withMessage:(NSString *)msg {
    NSLog(@"Stream: %s - %@", r5_string_for_status(statusCode), msg);
}

@end
